==> ejc-bfyjerp-impl-3.0.0-20241121.071822-56-sources.jar: com/ejianc/business/oa/bean/CertHumanChangeEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-证书人员申请表-变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_cert_human_apply_change")
public class CertHumanChangeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="apply_id")
    private Long applyId; // 申请表
    @TableField(value="code")
    private String code; // 编号
    @TableField(value="name")
    private String name; // 员工名称
    @TableField(value="sex")
    private Integer sex; // 性别 1：男 2：女
    @TableField(value="age")
    private Integer age; // 年龄
    @TableField(value="org_id")
    private Long orgId; // 组织ID
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="human_type")
    private Integer humanType; // 人员类别
    @TableField(value="human_type_name")
    private String humanTypeName; // 人员类别
    @TableField(value="id_card")
    private String idCard; // 身份证号码
    @TableField(value="cert")
    private String cert; // 证书情况
    @TableField(value="cert_name")
    private String certName; // 证书情况
    @TableField(value="cert_mny")
    private BigDecimal certMny; // 证书费用
    @TableField(value="pay_type")
    private Integer payType; // 付款方式
    @TableField(value="pay_type_name")
    private String payTypeName; // 付款方式
    @TableField(value="title_query")
    private Integer titleQuery; // 职称网查
    @TableField(value="title_query_name")
    private String titleQueryName; // 职称网查
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="compatibility")
    private String compatibility; // 配合度

    public String getCompatibility() {
        return compatibility;
    }

    public void setCompatibility(String compatibility) {
        this.compatibility = compatibility;
    }
    
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getCert() {
        return cert;
    }

    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }
    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }
    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }
    public Integer getTitleQuery() {
        return titleQuery;
    }

    public void setTitleQuery(Integer titleQuery) {
        this.titleQuery = titleQuery;
    }
    public String getTitleQueryName() {
        return titleQueryName;
    }

    public void setTitleQueryName(String titleQueryName) {
        this.titleQueryName = titleQueryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250117.082305-105-sources.jar: com/ejianc/business/oa/bean/CertHumanChangeEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-证书人员申请表-变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_cert_human_apply_change")
public class CertHumanChangeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="apply_id")
    private Long applyId; // 申请表
    @TableField(value="code")
    private String code; // 编号
    @TableField(value="name")
    private String name; // 员工名称
    @TableField(value="sex")
    private Integer sex; // 性别 1：男 2：女
    @TableField(value="age")
    private Integer age; // 年龄
    @TableField(value="org_id")
    private Long orgId; // 组织ID
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="human_type")
    private Integer humanType; // 人员类别
    @TableField(value="human_type_name")
    private String humanTypeName; // 人员类别
    @TableField(value="id_card")
    private String idCard; // 身份证号码
    @TableField(value="cert")
    private String cert; // 证书情况
    @TableField(value="cert_name")
    private String certName; // 证书情况
    @TableField(value="cert_mny")
    private BigDecimal certMny; // 证书费用
    @TableField(value="pay_type")
    private Integer payType; // 付款方式
    @TableField(value="pay_type_name")
    private String payTypeName; // 付款方式
    @TableField(value="title_query")
    private Integer titleQuery; // 职称网查
    @TableField(value="title_query_name")
    private String titleQueryName; // 职称网查
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="compatibility")
    private String compatibility; // 配合度

    @TableField(value="province")
    private String province; // 省份
    @TableField(value="purpose")
    private String purpose; // 用途

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }

    public String getCompatibility() {
        return compatibility;
    }

    public void setCompatibility(String compatibility) {
        this.compatibility = compatibility;
    }
    
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Integer getAge() {
        return age;
    }

    public void setAge(Integer age) {
        this.age = age;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getCert() {
        return cert;
    }

    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }
    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }
    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }
    public Integer getTitleQuery() {
        return titleQuery;
    }

    public void setTitleQuery(Integer titleQuery) {
        this.titleQuery = titleQuery;
    }
    public String getTitleQueryName() {
        return titleQueryName;
    }

    public void setTitleQueryName(String titleQueryName) {
        this.titleQueryName = titleQueryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    
}
